==> snipe-it-7.1.17.zip: snipe-it-7.1.17/resources/lang/ms-MY/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Pengguna ini boleh log masuk',
    'activated_disabled_help_text' => 'Anda tidak boleh kemaskini status pengaktifan akaun anda sendiri.',
    'assets_user'       => 'Serahkan harta kepada :nama',
    'bulk_update_warn'	=> 'Anda akan menyunting sifat: user_count pengguna. Sila ambil perhatian bahawa anda tidak boleh mengubah atribut pengguna anda sendiri menggunakan borang ini, dan mesti membuat pengeditan kepada pengguna anda sendiri secara individu.',
    'bulk_update_help'	=> 'Borang ini membolehkan anda mengemas kini berbilang pengguna sekaligus. Hanya isikan medan yang perlu anda ubah. Mana-mana medan yang dibiarkan kosong akan kekal tidak berubah.',
    'current_assets'    => 'Aset yang sedang diperiksa kepada pengguna ini',
    'clone'             => 'Pendua Nama',
    'contact_user'      => 'Hunungi :nama',
    'edit'              => 'Kemaskini Pengguna',
    'filetype_info'     => 'Filetype yang dibenarkan adalah png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, dan rar.',
    'history_user'      => 'Sejarah untuk :nama',
    'info'				=> 'Maklumat',
    'restore_user'		=> 'Klik di sini untuk memulihkannya.',
    'last_login'        => 'Log masuk terakhir',
    'ldap_config_text'  => 'Tetapan konfigurasi LDAP boleh didapati Admin> Tetapan. Lokasi (pilihan) yang dipilih akan ditetapkan untuk semua pengguna yang diimport.',
    'print_assigned'    => 'Cetak Semua yang Diperuntukkan',
    'email_assigned'    => 'Email List of All Assigned',
    'user_notified'     => 'User has been emailed a list of their currently assigned items.',
    'auto_assign_label' => 'Include this user when auto-assigning eligible licenses',
    'auto_assign_help'  => 'Skip this user in auto assignment of licenses',
    'software_user'     => 'Perisian diagihkan kepada :nama',
    'send_email_help'   => 'Anda mesti memberikan alamat e-mel untuk pengguna ini menghantar bukti kelayakan kepada mereka. Bukti kelayakan e-mel hanya boleh dilakukan pada penciptaan pengguna. Kata laluan disimpan dalam cincang sehala dan tidak boleh diambil semula setelah disimpan.',
    'view_user'         => 'Papar Pengguna :nama',
    'usercsv'           => 'Fail CSV',
    'two_factor_admin_optin_help' => 'Tetapan admin semasa anda membenarkan penguatkuasaan selektif pengesahan dua faktor.',
    'two_factor_enrolled' => '2FA Device Enrolled',
    'two_factor_active'   => '2FA Aktif',
    'user_deactivated'  => 'User cannot login',
    'user_activated'  => 'User can login',
    'activation_status_warning' => 'Do not change activation status',
    'group_memberships_helpblock' => 'Only superadmins may edit group memberships.',
    'superadmin_permission_warning' => 'Only superadmins may grant a user superadmin access.',
    'admin_permission_warning' => 'Only users with admins rights or greater may grant a user admin access.',
    'remove_group_memberships' => 'Remove Group Memberships',
    'warning_deletion_information' => 'You are about to checkin ALL items from the :count user(s) listed below. Super admin names are highlighted in red.',
    'update_user_assets_status' => 'Update all assets for these users to this status',
    'checkin_user_properties' => 'Check in all properties associated with these users',
    'remote_label'   => 'This is a remote user',
    'remote'   => 'Remote',
    'remote_help' => 'This can be useful if you need to filter by remote users who never or rarely come into your physical locations.',
    'not_remote_label' => 'This is not a remote user',
    'vip_label' => 'VIP user',
    'vip_help' => 'This can be helpful to mark important people in your org if you would like to handle them in special ways.',
    'create_user' => 'Create a user',
    'create_user_page_explanation' => 'This is the account information you will use to access the site for the first time.',
    'email_credentials' => 'Email credentials',
    'email_credentials_text' => 'Email my credentials to the email address above',
    'next_save_user' => 'Next: Save User',
    'all_assigned_list_generation' => 'Generated on:',
    'email_user_creds_on_create' => 'Email this user their credentials?',
];

==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/ms-MY/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Pengguna ini boleh log masuk',
    'activated_disabled_help_text' => 'Anda tidak boleh kemaskini status pengaktifan akaun anda sendiri.',
    'assets_user'       => 'Serahkan harta kepada :nama',
    'bulk_update_warn'	=> 'Anda akan menyunting sifat: user_count pengguna. Sila ambil perhatian bahawa anda tidak boleh mengubah atribut pengguna anda sendiri menggunakan borang ini, dan mesti membuat pengeditan kepada pengguna anda sendiri secara individu.',
    'bulk_update_help'	=> 'Borang ini membolehkan anda mengemas kini berbilang pengguna sekaligus. Hanya isikan medan yang perlu anda ubah. Mana-mana medan yang dibiarkan kosong akan kekal tidak berubah.',
    'current_assets'    => 'Aset yang sedang diperiksa kepada pengguna ini',
    'clone'             => 'Pendua Nama',
    'contact_user'      => 'Hunungi :nama',
    'edit'              => 'Kemaskini Pengguna',
    'filetype_info'     => 'Filetype yang dibenarkan adalah png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, dan rar.',
    'history_user'      => 'Sejarah untuk :nama',
    'info'				=> 'Maklumat',
    'restore_user'		=> 'Klik di sini untuk memulihkannya.',
    'last_login'        => 'Log masuk terakhir',
    'ldap_config_text'  => 'Tetapan konfigurasi LDAP boleh didapati Admin> Tetapan. Lokasi (pilihan) yang dipilih akan ditetapkan untuk semua pengguna yang diimport.',
    'print_assigned'    => 'Cetak Semua yang Diperuntukkan',
    'email_assigned'    => 'Email List of All Assigned',
    'user_notified'     => 'User has been emailed a list of their currently assigned items.',
    'users_notified'    => 'The user has been emailed a list of their currently assigned items.|:count users have been emailed a list of their currently assigned items.',
    'users_notified_warning' => ':count user has been emailed a list of their currently assigned items, however :no_email users did not have an email address so could not be emailed.|:count users have been emailed a list of their currently assigned items, however :no_email user(s) did not have an email address so could not be emailed.',
    'auto_assign_label' => 'Include this user when auto-assigning eligible licenses',
    'auto_assign_help'  => 'Skip this user in auto assignment of licenses',
    'software_user'     => 'Perisian diagihkan kepada :nama',
    'send_email_help'   => 'Anda mesti memberikan alamat e-mel untuk pengguna ini menghantar bukti kelayakan kepada mereka. Bukti kelayakan e-mel hanya boleh dilakukan pada penciptaan pengguna. Kata laluan disimpan dalam cincang sehala dan tidak boleh diambil semula setelah disimpan.',
    'view_user'         => 'Papar Pengguna :nama',
    'usercsv'           => 'Fail CSV',
    'two_factor_admin_optin_help' => 'Tetapan admin semasa anda membenarkan penguatkuasaan selektif pengesahan dua faktor.',
    'two_factor_enrolled' => '2FA Device Enrolled',
    'two_factor_active'   => '2FA Aktif',
    'user_deactivated'  => 'User cannot login',
    'user_activated'  => 'User can login',
    'activation_status_warning' => 'Do not change activation status',
    'group_memberships_helpblock' => 'Only superadmins may edit group memberships.',
    'superadmin_permission_warning' => 'Only superadmins may grant a user superadmin access.',
    'admin_permission_warning' => 'Only users with admins rights or greater may grant a user admin access.',
    'remove_group_memberships' => 'Remove Group Memberships',
    'warning_deletion_information' => 'You are about to checkin ALL items from the :count user(s) listed below. Super admin names are highlighted in red.',
    'update_user_assets_status' => 'Update all assets for these users to this status',
    'checkin_user_properties' => 'Check in all properties associated with these users',
    'remote_label'   => 'This is a remote user',
    'remote'   => 'Remote',
    'remote_help' => 'This can be useful if you need to filter by remote users who never or rarely come into your physical locations.',
    'not_remote_label' => 'This is not a remote user',
    'vip_label' => 'VIP user',
    'vip_help' => 'This can be helpful to mark important people in your org if you would like to handle them in special ways.',
    'create_user' => 'Create a user',
    'create_user_page_explanation' => 'This is the account information you will use to access the site for the first time.',
    'email_credentials' => 'Email credentials',
    'email_credentials_text' => 'Email my credentials to the email address above',
    'next_save_user' => 'Next: Save User',
    'all_assigned_list_generation' => 'Generated on:',
    'email_user_creds_on_create' => 'Email this user their credentials?',
];
